EXPORTS
	??0RHtiIPCommServer@@QAE@XZ @ 1 NONAME ; RHtiIPCommServer::RHtiIPCommServer(void)
	?CancelReceive@RHtiIPCommServer@@QAEXXZ @ 2 NONAME ; void RHtiIPCommServer::CancelReceive(void)
	?CancelSend@RHtiIPCommServer@@QAEXXZ @ 3 NONAME ; void RHtiIPCommServer::CancelSend(void)
	?Close@RHtiIPCommServer@@QAEXXZ @ 4 NONAME ; void RHtiIPCommServer::Close(void)
	?Connect@RHtiIPCommServer@@QAEHXZ @ 5 NONAME ; int RHtiIPCommServer::Connect(void)
	?GetReceiveBufferSize@RHtiIPCommServer@@QBEHXZ @ 6 NONAME ; int RHtiIPCommServer::GetReceiveBufferSize(void) const
	?GetSendBufferSize@RHtiIPCommServer@@QBEHXZ @ 7 NONAME ; int RHtiIPCommServer::GetSendBufferSize(void) const
	?Receive@RHtiIPCommServer@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 8 NONAME ; void RHtiIPCommServer::Receive(class TDes8 &, class TRequestStatus &)
	?Send@RHtiIPCommServer@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 9 NONAME ; void RHtiIPCommServer::Send(class TDesC8 const &, class TRequestStatus &)
	?Version@RHtiIPCommServer@@QBE?AVTVersion@@XZ @ 10 NONAME ; class TVersion RHtiIPCommServer::Version(void) const

